@@ -1,4 +1,5 @@
 from .matrices import RowMatrix
 from .save import save, pack, subset
-from .load import load, getdims, subtoind, indtosub
-from .datasets import DataSets
\ No newline at end of file
+from .load import getdims, subtoind, indtosub
+from .datasets import DataSets
+from .context import ThunderContext
\ No newline at end of file
