@@ -35,7 +35,7 @@ def install_thunder(master, opts):
     ssh(master, opts, "rm -rf thunder && git clone https://github.com/freeman-lab/thunder.git")
     ssh(master, opts, "chmod u+x thunder/python/bin/build")
     ssh(master, opts, "thunder/python/bin/build")
-    ssh(master, opts, "source ~/.bash_profile && pip install mpld3")
+    ssh(master, opts, "source ~/.bash_profile && pip install mpld3 && pip install seaborn")
     ssh(master, opts, "rm /root/pyspark_notebook_example.ipynb")
     ssh(master, opts, "echo 'export SPARK_HOME=/root/spark' >> /root/.bash_profile")
     ssh(master, opts, "echo 'export PYTHONPATH=/root/thunder/python' >> /root/.bash_profile")
@@ -53,23 +53,6 @@ def install_thunder(master, opts):
     print "\n"
 
 
-def load_data(master, opts):
-    """ 
-    Load an example data set into a Spark EC2 cluster
-    TODO: replace with URL once we've hosted public data
-    """
-    print "Transferring example data to the cluster..."
-    ssh(master, opts, "/root/ephemeral-hdfs/bin/stop-all.sh")
-    ssh(master, opts, "/root/ephemeral-hdfs/bin/start-all.sh")
-    time.sleep(10)
-    ssh(master, opts, "/root/ephemeral-hdfs/bin/hadoop distcp s3n://thunder.datasets/test/iris.txt hdfs:///data")
-    print "\n\n"
-    print "-------------------------------"
-    print "Example data successfully loaded!"
-    print "-------------------------------"
-    print "\n"
-
-
 def setup_cluster(conn, master_nodes, slave_nodes, opts, deploy_ssh_key):
     """Modified version of the setup_cluster function (borrowed from spark-ec.py)
     in order to manually set the folder with the deploy code"""
@@ -151,7 +134,7 @@ if __name__ == "__main__":
         opts.wait = 160
         opts.hadoop_major_version = "1"
         opts.ganglia = True
-        opts.spark_version = "1.0.1"
+        opts.spark_version = "1.0.2"
         opts.swap = 1024
         opts.worker_instances = 1
         opts.master_opts = ""
@@ -159,15 +142,7 @@ if __name__ == "__main__":
         if opts.resume:
             (master_nodes, slave_nodes) = get_existing_cluster(conn, opts, cluster_name)
         else:
-            check_group = get_or_make_group(conn, cluster_name + "-master")
-            if check_group.rules == []:
-                new_group = True
-            else:
-                new_group = False
             (master_nodes, slave_nodes) = launch_cluster(conn, opts, cluster_name)
-            if new_group:
-                master_group = get_or_make_group(conn, cluster_name + "-master")
-                master_group.authorize('tcp', 8888, 8888, '0.0.0.0/0')
 
         wait_for_cluster(conn, opts.wait, master_nodes, slave_nodes)
         setup_cluster(conn, master_nodes, slave_nodes, opts, True)
@@ -195,10 +170,6 @@ if __name__ == "__main__":
         elif action == "install":
             install_thunder(master, opts)
 
-        # Load example data into the cluster
-        elif action == "loaddata":
-            load_data(master, opts)
-
         # Destroy the cluster
         elif action == "destroy":
             response = raw_input("Are you sure you want to destroy the cluster " + cluster_name +
@@ -213,4 +184,7 @@ if __name__ == "__main__":
             for inst in slave_nodes:
                 inst.terminate()
 
+        else:
+            raise NotImplementedError("action: " + action + "not recognized")
+
 
